/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Linky
 *
 * The Initial Developer of the Original Code is Henrik Gemal.
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Henrik Gemal <linky@gemal.dk> http://gemal.dk
 *   Jens Bannmann <jens.b@web.de>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// product related settings
// you can change these
const myProductName = "Paste and Go";
const myProductRegKey = "pasteandgo";
const myProductRegVersion = "0.4.3";
const myJarFileName = "pasteandgo.jar";
const myLocales = new Array(); // the locales available
const myJarCheckDupe = 1; // check if myJarFileName exist both in personal chrome folder and global chrome folder

// global settings
// dont change these
const sysChromeGlobal = getFolder("Chrome");
const sysChromeGlobalJar = getFolder("Chrome", myJarFileName);
const sysChromeUser = getFolder("Current User","chrome");
const sysChromeUserJar = getFolder("Current User", "chrome/" + myJarFileName);
const errPage = "http://devedge.netscape.com/library/manuals/2001/xpinstall/1.0/err.html";

var doInstall = true;
var installToProfile;

if (myJarCheckDupe && File.exists(sysChromeGlobalJar) && File.exists(sysChromeUserJar)) {
  alert(myProductName + " is installed in BOTH the personal chrome folder:\n" + sysChromeUserJar + "\nand the global chrome folder:\n" + sysChromeGlobalJar + "\n\nThis will cause weird behaviour. Please delete one of the instances!");
  doInstall = false;
} else {
  // Can we install in the personal profile folder?
  if (buildID && buildID >= 2003030700) {
    if (File.exists(sysChromeGlobalJar) || File.exists(sysChromeUserJar)) {
      installToProfile = File.exists(sysChromeUserJar);
      msg = myProductName + " " + myProductRegVersion + " will be installed "
            + "into " + (installToProfile ? "your current profile"
                                          : "the global chrome folder")
            + ", as a previous installation has been found there.\nIf you want "
            + "to change this, click 'Cancel' and remove the old installation "
            + "before installing again.";
      if (confirm(msg) == 0) { // 0 = Cancel, 1 = OK
        doInstall = false;
      }
    } else {
      msg = myProductName + " " + myProductRegVersion + " can be installed "
            + "into two locations.\nIf you want to make " + myProductName + " "
            + "available to all users by installing into the global chrome "
            + "directory, click 'OK' (this may require administrator "
            + "privileges).\nOtherwise, click 'Cancel' to install it into your "
            + "current profile directory.";
      installToProfile = (confirm(msg) == 0); // 0 = Cancel, 1 = OK
    }
  } else {
    installToProfile = false;
  }
}

// did the user cancel?
if (!doInstall) {
  cancelInstall();
} else {
  var err;
  var err_tmp;
  // init the installation
  err_tmp = initInstall(myProductName, myProductRegKey, myProductRegVersion);
  if (err_tmp) {
    err = err_tmp;
  }
  
  logComment(myProductName + " version " + myProductRegVersion + " being installed on " + buildID);
  logComment("Installing " + (installToProfile ? "to profile" : "globally"));
  
  // add the jar file
  if (!err) {
    err_tmp = addFile(myProductName, "chrome/" + myJarFileName,
                      (installToProfile ? sysChromeUser : sysChromeGlobal),
                      "");
    if (err_tmp) {
      logComment("Problem adding jar file. Error code: " + err_tmp);
      err = err_tmp;
    } else {
      logComment("ok adding jar file.");
    }
  }
  
  // register the content
  if (!err) {
    if (installToProfile) {
      err_tmp = registerChrome(PACKAGE | PROFILE_CHROME, sysChromeUserJar, "content/" + myProductRegKey + "/");
    } else {
      err_tmp = registerChrome(PACKAGE | DELAYED_CHROME, sysChromeGlobalJar, "content/" + myProductRegKey + "/");
    }
    if (err_tmp) {
      logComment("Problem registering the content chrome. Error code: " + err_tmp);
      err = err_tmp;
    } else {
      logComment("ok registering the content chrome.");
    }
  }
  
  // register the locale
  if (!err) {
    if (installToProfile) {
      for (var i = 0; i < myLocales.length; i++) {
        err_tmp = registerChrome(LOCALE | PROFILE_CHROME, sysChromeUserJar, "locale/" + myLocales[i] + "/" + myProductRegKey +"/");
        if (err_tmp)
          break;
      }
    } else {
      for (var i = 0; i < myLocales.length; i++) {
        err_tmp = registerChrome(LOCALE | DELAYED_CHROME, sysChromeGlobalJar, "locale/" + myLocales[i] + "/" + myProductRegKey+ "/");
        if (err_tmp) {
          break;
        }
      }
    }
    if (err_tmp) {
      logComment("Problem registering the locale chrome. Error code: " + err_tmp);
      err = err_tmp;
    } else {
      logComment("ok registering the locale chrome.");
    }
  }
  
  // do the install
  if (!err) {
    err_tmp = performInstall();
    if (err_tmp < 0) {
      logComment("Problem performing install. Error code: " + err_tmp);
      err = err_tmp;
    } else {
      alert(myProductName + " version " + myProductRegVersion
            + " has been successfully installed.\n\n"
            + "Please restart your browser to complete the installation.");
    }
  }
  
  // did it work?
  if (err) {
    logComment("Problem installing. Error code: " + err + ". Error codes can been seen at: " + errPage);
    alert(myProductName + " version " + myProductRegVersion + " was not installed!\nError code: " + err + "\n\nError codes can be seen at:\n" + errPage)
    cancelInstall(err);
  }
}
